AddRecord
ApplySortOrder
catalog
CFs
ContextObject
CustomField
CustomFields
LimitToAdded
LimitToCatalog
LimitToChildType
LimitToDefaultValuesSupportedTypes
LimitToGlobal
LimitToGlobalOrObjectId
LimitToGlobalOrQueue
LimitToGrouping
LimitToLookupType
LimitToNotAdded
LimitToObjectId
LimitToParentType
LimitToQueue
LookupType
NewItem
ObjectId
OR'd
QUEUEID
RT
SearchBuilder
SetContextObject
