ActiveStatusArray
ActiveStatuses
AUTOLOAD
DBIx
InactiveStatusArray
InactiveStatuses
IsActiveStatus
IsInactiveStatus
IsValidStatus
LifecycleObj
LifecycleType
RT
SearchBuilder
SetLifecycle
StatusArray
unenforced
ValidateLifecycle
