AddRecord
CustomField
CustomFieldObj
CustomFieldValue
CustomFieldValues
datetime
LastUpdated
LastUpdatedBy
SetCategory
SetCustomField
SetCustomFieldObj
SetDescription
SetName
SetSortOrder
SortOrder
ValidateName
varchar
