BOOL
canonicalize
CanonicalizeCharset
charset
ContentType's
DecodeMIMEWordsToUTF
EncodeFromToWithCroak
FindOrGuessCharset
gbk
GuessCharset
html
iff
incomding
Init
Initializes
IsOut
IsTextualContentType
localization
MIMEHead
mimewords
MUA
MUAs
PreserveWords
rfc
RT
SetMIMEEntityToEncoding
SetMIMEEntityToUTF
SetMIMEHeadToEncoding
unicode
utf
