CheckRight
config
CreateLifecycle
CurrentUser
DefaultOnCreate
DefaultStatus
dropdown
ForLocalization
HasMoveMap
IsActive
IsInactive
IsInitial
IsTransition
IsValid
LifecycleObj
ListAll
Localization
MoveMap
NewConfig
NewLayout
NoMoveMaps
RightsDescription
RT
RT's
StatusType
undef
UpdateLifecycle
UpdateLifecycleLayout
UpdateMaps
ValidateLifecycle
ValidateLifecycleMaps
