ACL
AddHeader
Bcc
ContentAsMIME
ContentEncoding
ContentLength
ContentType
crypto
CryptStatus
CurrentUserCanSee
datetime
DelHeader
EncodedHeaders
FriendlyContentLength
GetAllHeaders
GetHeader
hashref
hashrefs
IsAttachmentContentDisposition
IsMessageContentType
KiB
localized
longblob
longtext
MessageId
MiB
multipart
NiceHeaders
OriginalContent
OriginalEncoding
paramhash
ParentObj
ParseStatus
regex
ReplaceContent
ReplaceHeaders
RT
RT's
SetContent
SetContentEncoding
SetContentType
SetFilename
SetHeader
SetHeaders
SetMessageId
SetParent
SetSubject
SetTransactionId
SMIME
SplitHeaders
TransactionId
TransactionObj
undef
varchar
