ACL
ACLEquivalenceObjects
ACLS
ApplyQuoteWrap
BriefDescription
BriefDescriptionAsHTML
CFs
config
ContentObj
ContentType
CurrentUserCanSee
CustomField
CustomFieldLookupType
datetime
DeferredRecipients
freq
HasContent
hashref
HasRight
html
IsDisplayableTextualContentType
IsInbound
IsTextualContentType
LoadCustomFieldByIdentifier
localized
LookupType
NewReference
NewReferenceObject
NewValue
ObjectId
ObjectType
OldReference
OldReferenceObject
OldValue
paramhash
PreferredContentType
QuoteContent
QuoteHeader
QuoteWrap
QuoteWrapWidth
ReferenceType
requestor
rfc
RT
RT's
SetData
SetField
SetNewReference
SetNewValue
SetObjectId
SetObjectType
SetOldReference
SetOldValue
SetReferenceType
SetTimeTaken
SetType
SquelchMailTo
susp
TimeTaken
TODO
txn
undef
UpdateCustomFields
varchar
