ACL
ACLs
AddMember
AdminCc
AdminGroup
BOOL
CachedGroupMembers
CanonicalizeName
CreateACLEquivalenceGroup
CreateRoleGroup
CreateUserDefinedGroup
CurrentUser
CurrentUserCanCreate
CurrentUserCanModify
CurrentUserCanSee
datetime
DeepMembersObj
DeleteMember
denormalizes
GroupMember
GroupMembers
GroupMembersObj
HasMember
HasMemberRecursively
honored
InsideTransaction
LastUpdated
LastUpdatedBy
LoadACLEquivalenceGroup
LoadRoleGroup
LoadSystemInternalGroup
LoadUserDefinedGroup
MemberEmailAddresses
MemberEmailAddressesAsString
MembersObj
msg
param
paramhash
PrincipalId
PrincipalObj
RecordTransaction
Requestor
RT
RT's
SeeGroup
SelfDescription
SetDescription
SetDisabled
SetDomain
SetInstance
SetName
SingleMemberRoleGroup
undef
URI
UserMembersObj
ValidateName
ValidateNameForDomain
ValidateRoleGroup
ValidateUserDefinedName
varchar
