args
arrayref
attr
auth
Authen
autocreated
AutoCreateNonExternalUsers
automagically
CFs
cn
co
com
CompanyPhone
db
DBI
dc
EmailAddress
employeeId
ExternalAuth
ExternalAuthPriority
ExternalInfoPriority
ExternalSettings
hashref
inetOrgPerson
ldap
multivalue
objectClass
organization
ou
physicalDeliveryOfficeName
pm
postalCode
qw
RDBMS
RealName
requestors
rt
sAMAccountName
SiteConfig
SSO
streetAddress
telephoneNumber
UserAutocreateDefaultsOnLogin
UserCF
WorkPhone
YYY
