CurrentUser
EquivObjects
GroupSearchFields
Hashref
IncludeSuperusers
IncludeSystemRights
LimitToDeleted
LimitToEnabled
LimitToRolesForObject
LimitToRolesForQueue
LimitToRolesForSystem
LimitToRolesForTicket
LimitToSystemInternalGroups
LimitToUserDefinedGroups
PrincipalId
PrincipalsAlias
RIGHTNAME
RT
SimpleSearch
SystemInternal
undef
UnLimit
UserDefined
WithMember
WithRight
