BaseObj
BaseURI
datetime
DisplayTypes
LastUpdated
LastUpdatedBy
LoadByParams
LocalBase
LocalTarget
PARAMHASH
RT
SetBase
SetLocalBase
SetLocalTarget
SetTarget
SetType
TargetObj
TargetURI
undef
URI
URIs
varchar
