CachedGroupMember
CachedGroupMembers
GroupId
GroupMember
GroupObj
ImmediateParent
ImmediateParentId
ImmediateParentObj
MemberId
MemberObj
PARAMHASH
RT
SetDisabled
SetDisableds
SetGroupId
SetImmediateParentId
SetMemberId
SetVia
smallint
submembers
