ACL
ACLs
AddRoleMember
AddWatcher
AdminCc
AdminCcAddresses
AdminCcs
AdminQueue
ARGS
CcAddresses
Ccs
CommentAddress
CorrespondAddress
CurrentUserCanCreate
CurrentUserCanModify
CurrentUserCanSee
CustomField
CustomFields
CustomRoles
datetime
DeleteRoleMember
DeleteWatcher
IsAdminCc
IsCc
IsManageableRoleGroupType
IsWatcher
LastUpdated
LastUpdatedBy
ManageableRoleGroupTypes
ok
param
PrincipalId
requestor
RT
SeeQueue
SetCommentAddress
SetCorrespondAddress
SetDescription
SetDisabled
SetLifecycle
SetName
SetSign
SetSubjectTag
ShowQueue
smallint
SortOrder
SubjectTag
TicketCustomFields
TicketTransactionCustomFields
undef
ValidateName
varchar
