AddToObject
AdminClass
AppliedTo
ArticleCustomFields
CurrentUserCanCreate
CurrentUserCanModify
CurrentUserCanSee
CustomFieldObject
datetime
EscapeHTML
IncludeArticleCFTitle
IncludeArticleCFValue
IncludedArticleCustomFields
IncludeName
IncludeSummary
IsApplied
LastUpdated
LastUpdatedBy
NotAppliedTo
ObjectClass
PARAMHASH
RemoveFromObject
RT
SeeClass
SetDescription
SetDisabled
SetName
SetSortOrder
SortOrder
varchar
