config
ContentEncoding
ContentType
CurrentUserCanSee
CustomField
CustomFieldObj
datetime
FillInTemplateURL
GetOCFVCacheKey
IncludeContentForValue
LargeContent
LastUpdated
LastUpdatedBy
LinkValueTo
LoadByCols
LoadByTicketContentAndCustomField
longblob
ObjectCustomFieldValue
ObjectId
ObjectType
OCFV
RT's
SeeCustomField
SetContent
SetContentEncoding
SetContentType
SetCustomField
SetDisabled
SetLargeContent
SetObjectId
SetObjectType
SetSortOrder
smallint
SortOrder
UI
undef
URI
ValueIncludeURL
ValueLinkURL
varchar
WebBaseURL
WebDomain
WebPath
WebPort
webui
WebURL
