AddAttachment
AddAttachments
AddAttachmentsFromHeaders
AddTicket
AddTickets
AttachableFromTransaction
AttachExisting
AttachTickets
AutoReply
Bcc
behavior
charset
CleanSlate
config
emailaddress
EncodeToMIME
GetFriendlyName
ISA
MIMEEncodeString
MIMEObj
multipart
NoSquelch
PseudoReference
RecipientFilter
RecordNote
RecordOutgoingMailTransaction
RemoveInappropriateRecipients
rt
RT's
SendEmail
SendMessage
SetFrom
SetHeader
SetHeaderAsEncoding
SetReferencesHeaders
SetReturnAddress
SetRTSpecialHeaders
SetSubject
SetSubjectToken
specialized
SquelchMailTo
subclassed
TODO
undef
YourAction
