Accessor
acl
AddUpgradeHistory
AvailableRights
config
ConfigCacheNeedsUpdate
CurrentUserCanSee
CustomRoleCacheNeedsUpdate
ExternalStorage
ExternalStorageDirectLink
ExternalStorageURLFor
hashref
LifecycleCacheNeedsUpdate
QueueCacheNeedsUpdate
RightCategories
RT
RT's
SelectQueue
SQLTimeout
SuperUser
UI
undef
UpgradeHistory
UserMessages
