ACL
ACLEquivalenceObjects
ACLOnly
ACLOnlyInEquiv
ACLs
AddRoleMember
AdminCc
AppliesToObjectPredicate
arrayref
behavior
Canonicalized
CanonicalizePrincipal
CheckRight
codebase
CreateGroupPredicate
CreateRoleGroup
CreateRoleGroups
CustomRole
CustomRoleObj
DeleteRoleMember
denormalized
EmailAddress
EmailParser
EquivClasses
hashref
HasRole
LabelForRole
LabelGenerator
ParseEmailAddress
ParseInputPrincipals
PrincipalId
RegisterRole
Requestor
Requestors
RoleAddresses
RoleGroup
RT
SortOrder
truthy
UI
undef
UnregisterRole
UserDefined
