ApplicableTransTypes
datetime
ExecModule
IsApplicable
LastUpdated
LastUpdatedBy
LoadCondition
RT
ScripCondition
SetApplicableTransTypes
SetArgument
SetDescription
SetExecModule
SetName
TicketObj
TransactionObj
ValidateName
varbinary
varchar
