ACLs
arrayref
EquivObjects
Hashref
IncludeSubgroupMembers
IncludeSuperusers
IncludeSystemRights
IncludeUnprivileged
LimitToDeleted
LimitToEmail
LimitToEnabled
LimitToEndUsers
LimitToPrivileged
LimitToUnprivileged
MemberOfGroup
PrincipalsAlias
rt
SimpleSearch
undef
UserSearchFields
WhoBelongToGroups
WhoHaveRight
