AddLink
ClassObj
CurrentUserCanSee
CustomFields
datetime
hotlist
LastUpdated
LastUpdatedBy
LoadByInclude
LoadByNameAndClass
PARAM
paramhash
RT
SetClass
SetDisabled
SetName
SetParent
SetSortOrder
SetSummary
SetURI
ShowArticle
SortOrder
undef
URI
URIObj
ValidateName
varchar
