AttachContentLimit
AttachLimit
cfid
cfname
CFs
ContentType
CustomFieldDecipher
CustomFieldLimit
CustomFieldNameLimit
CustomFields
DateLimit
DBIx
EnumLimit
FromSQL
IdLimit
IntLimit
LimitToTicket
LookupType
NewReference
NewValue
ObjectCustomFieldValueLimit
ObjectType
OldReference
OldValue
ProcessRestrictions
ReferenceType
RT
SearchBuilder
SortFields
StringLimit
TICKETID
