ACL
ACLEquivalenceObjects
AddedTo
AddToObject
AddValue
AddValueForObject
AdminCustomField
Autrijus
BasedOn
Bool
canonicalization
CanonicalizeClass
canonicalizer
catalog
CFs
Config
ContentType
ContextObject
CurrentUserCanCreate
CurrentUserCanModify
CurrentUserCanSee
CustomField
CustomFieldLookupType
CustomFieldValues
CustomFieldValuesCanonicalizers
CustomFieldValuesSources
CustomGroupings
datetime
DefaultRenderType
DeleteValue
DeleteValueForObject
Dropdown
EditCustomFields
EntryHint
FriendlyPattern
FriendlyType
HasRenderTypes
IncludeContentForValue
IncludeDisabled
IncludeGlobal
IsAdded
IsAddedToAny
IsCanonicalizeType
IsExternalValues
IsSelectionType
IsValidRegex
LargeContent
LastUpdated
LastUpdatedBy
LinkValueTo
LoadByName
LoadByNameAndCatalog
LoadByNameAndQueue
LoadContextObject
LoadNameAndQueue
localized
localizing
LookupType
LookupTypes
MatchPattern
MaxValues
msg
NotAddedTo
ObjectCustomField
ObjectCustomFieldValues
ObjectId
ObjectType
param
paramhash
RecordClassFromLookupType
regex
RegisterBuiltInGroupings
RemoveFromObject
RenderType
RenderTypes
Retuns
RT
SeeCustomField
SetBasedOn
SetCanonicalizeClass
SetContextObject
SetDescription
SetDisabled
SetEntryHint
SetIncludeContentForValue
SetInitialCustomField
SetLinkValueTo
SetLookupType
SetMaxValues
SetName
SetPattern
SetRenderType
SetSortOrder
SetType
SetTypeComposite
SetValidationHint
SetValuesClass
ShowCustomFields
SingleValue
smallint
SortOrder
Str
TypeComposite
TypeComposites
undef
URLTemplate
ValidateCanonicalizeClass
ValidateContextObject
ValidateQueue
ValidateType
ValidateValue
ValidateValuesClass
ValidationHint
ValuesClass
ValuesForObject
varchar
