AddedTo
AddToObject
AdminCustomRoles
CurrentUserCanCreate
CurrentUserCanModify
CustomRole
datetime
EntryHint
GroupType
IsAdded
IsAddedToAny
LastUpdated
LastUpdatedBy
LookupType
MaxValues
NotAddedTo
ObjectId
ok
param
PARAMHASH
RemoveFromObject
RT
SetDescription
SetDisabled
SetEntryHint
SetLookupType
SetMaxValues
SetName
SingleValue
smallint
SortOrder
undef
UnlimitedValues
val
ValidateLookupType
ValidateName
varchar
